import QtQuick 1.1
import StatisticManager 1.0

Item{
    id: root
    anchors.fill: parent

    property int fontSize: 24
    property int topOffset: -150
    property int itemSpacing: 5
    property int itemColumnSpacing: 50

    property string beltMotorUsageMilesLabel: qsTr("Belt Motor Usage in Miles") + application.emptyString
    property string beltMotorUsageSecondLabel: qsTr("Belt Motor Usage in Seconds") + application.emptyString
    property string inclineMotorUsageSecondLabel: qsTr("Incline Motor Usage in Seconds") + application.emptyString
    property string staticBrakeEnagagementCountLabel: qsTr("Static Brake Engagement Count") + application.emptyString
    property string staticBrakeUsageRevolutionsLabel: qsTr("Static Brake Usage in Revolutions") + application.emptyString

    property string runHoursValue: Number(statisticManager.runHours/3600).toFixed(1) + " " + qsTr("Hours") + application.emptyString
    property string machineDistanceValue: options.metricUnits ? Globals.mileToKm(statisticManager.totalDistance/100).toFixed(2) + " " + qsTr("KM") : (statisticManager.totalDistance/100).toFixed(2) + " " + qsTr("miles") + application.emptyString
    property string distanceValue: options.metricUnits ? Globals.mileToKm(statisticManager.mileage/100).toFixed(2) + " " + qsTr("KM") : (statisticManager.mileage/100).toFixed(2) + " " + qsTr("miles") + application.emptyString

    Component.onCompleted: {
        statisticManager.getNucleusStatistics();
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsStatistics")
            diagnostics_screen.item.unselectScreen()
        }
    }

    Column{
        id: labels
        spacing: itemSpacing
        anchors.left: parent.left
        anchors.leftMargin: 200
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: topOffset

        Text{
            text: beltMotorUsageMilesLabel
            font.pointSize: fontSize
        }

        Text{
            text: beltMotorUsageSecondLabel
            font.pointSize: fontSize
        }

        Text{
            text: inclineMotorUsageSecondLabel
            font.pointSize: fontSize
        }

        Text{
            text: staticBrakeEnagagementCountLabel
            font.pointSize: fontSize
        }

        Text{
            text: staticBrakeUsageRevolutionsLabel
            font.pointSize: fontSize
        }

    }
    Column{
        id:values
        spacing: itemSpacing
        anchors.left: labels.right
        anchors.leftMargin: 200
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: topOffset

        Text{
            text: statisticManager.beltMotorUsageMile.toFixed(2);
            font.pointSize: fontSize
        }

        Text{
            text: statisticManager.beltMotorUsageSecond
            font.pointSize: fontSize
        }

        Text{
            text: statisticManager.inclineMotorUsageSecond
            font.pointSize: fontSize
        }

        Text{
            text: statisticManager.staticBrakeEngagementCount
            font.pointSize: fontSize
        }

        Text{
            text: statisticManager.staticBrakeUsageRevolutions
            font.pointSize: fontSize
        }

    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("press ENTER to select") + application.emptyString

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }
}
