import QtQuick 1.1
import VLCVideo 1.0

// Video window to play video
Rectangle  {
    id: root

    property string videoMRL
    property ListModel c360Modes: main.isLateralTrainer ? c360Modes_LateralTrainer : c360Modes_Elliptical
    property alias videoMRL: videoPlayer.mrl
    property variant c360program: workoutProgram.c360Program
    property int phase: c360program.currentPhase
    property string videoPath: "/data/video/Cardio360/" + (main.isLateralTrainer ? "Traverse" : "Spectrum")
    property string videoSubpath: options.modestyMode ? "Male" : (Math.random() >= 0.5 ? "Female" : "Male")
    property string introVideo: "Intro Clip.mp4"
    property int segmentTime: c360program.phaseTimeRemaining
    property bool skipIntroMode: main.isLateralTrainer
    property bool inIntroMode: !skipIntroMode

    signal playbackComplete()

    color: "white"
    anchors.fill: parent

    function beginWorkout() {
        root.inIntroMode = false
        if (setVideoTimer.running) {
            setVideoTimer.stop()
        }
        workoutManager.start()
        root.phaseChanged(phase)
    }

    Connections {
        target: workoutManager
        onWorkoutModeChanged: {
            if (mode === WorkoutRunData.COOL_DOWN_MODE) {
                if (root.inIntroMode) {
                    workoutManager.resume()
                }

                root.inIntroMode = false
            }
        }
    }

    Component.onCompleted: {
        // Set video on delay to avoid race condition where video is not set
        setVideoTimer.start()
    }

    Timer {
        id: setVideoTimer
        interval: 300
        running: false
        onTriggered: {
            if (skipIntroMode) {
                beginWorkout()
            } else {
                videoMRL = videoFullPath(introVideo)
                bannerForIntro.display()
            }
        }
    }

    onPhaseChanged: {
        if (root.inIntroMode) {
            return
        }

        var text = qsTranslate("C360ViewContainer", c360Modes.title(phase))
        root.phaseTitleChanged(text)
        videoMRL = videoFullPath(c360Modes.get(phase).video)
        console.log("videoMRL=", videoMRL)
    }

    function videoFullPath(path) {
        return "file://" + root.videoPath + "/" + videoSubpath + "/" + path
    }

    function stopVideo() {
        videoPlayer.stop()
    }

    color: "black"

    MouseArea {
        anchors.fill: parent
        onClicked: {
            fullscreenVideoFrame.showFullscreen(videoPlayer)
        }
    }

    VLCSurface {
        id: videoSurface

        player: videoPlayer
        aspect: videoPlayer.aspect
        playing: !videoPlayer.fullscreen && videoPlayer.playing

        anchors.fill: parent
    }

    VLCVideo {
        id: videoPlayer

        property bool fullscreen

        visible: true

        debug: false
        deinterlace: false
        onPlayCompleted: root.playbackComplete()
        loop: !inIntroMode
        onPlayCompleted: {
            if (inIntroMode) {
                beginWorkout()
            }
        }
    }

    Image {
        id: motionMan
        visible: !inIntroMode
        anchors {
            top: parent.top
            topMargin: 85
            left: parent.left
            leftMargin: 40
        }
        fillMode: Image.PreserveAspectFit
        smooth: true
        height: 260
        width: 262

        source: "graphics/c360/MotionMan/" + c360Modes.get(phase).icon
    }

    Text {
        id: instText
        width: 300
        visible: !inIntroMode
        anchors {
            right: parent.right
            rightMargin: 15
            bottom: segRect.top
            bottomMargin: 20
        }
        wrapMode: Text.WordWrap

        text: qsTranslate("C360ViewContainer", c360Modes.instructions(phase)) + application.emptyString
    }

    Text {
        id: guideTextForIntro
        wrapMode: Text.WordWrap
        width: 320
        visible: inIntroMode
        anchors {
            right: parent.right
            rightMargin: 15
            top: parent.top
            topMargin: 175
        }

        mrl: root.videoMRL ? "file://" + root.videoMRL : ""
    }
}

