// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import ".."

C360View {
    id: c360View
    property variant container
    width: 1000
    height: 406

    anchors.bottom: parent.bottom
    anchors.horizontalCenter: parent.horizontalCenter
    onPhaseTitleChanged: workoutScreen.showC360Message(title)

    ListModel {
        id: c360Modes_LateralTrainer

        function imagePath(productModel) {
            var model = brainboard.modelString ? brainboard.modelString : "TL1000"
            switch(brainboard.modelString) {
            case "TL1000":
                return options.modestyMode ? "graphics/c360/TL1000/Male/C360_Traverse_" : "graphics/c360/TL1000/Female/C360_Traverse_"
            }
        }

        function title(index) {
            return [ qsTr("START UP, PUSH OUTWARD"),
                    qsTr("PUSH INWARD"),
                    qsTr("LEG PUMPS OUTWARD"),
                    qsTr("SQUAT INWARD"),
                    qsTr("LEG PUMPS INWARD"),
                    qsTr("STAND ON TOES, PUSH OUTWARD"),
                    qsTr("SQUAT OUTWARD"),
                    qsTr("STAND ON TOES, PUSH INWARD"),
                    qsTr("RECOVER, PUSH OUTWARD")
                    ][index]
        }

        function instructionsList(index) {
            return [
                        [qsTr("Stand on Foot Pedals") ,qsTr("Push Outward"), qsTr("Move Body Side to Side")],
                        [qsTr("Stand on Foot Pedals"),qsTr("Push Inward"), qsTr("Move Body Side to Side") ],
                        [qsTr("Center Your Upper Body") ,qsTr("Remain Centered") ,qsTr("Push Outward") ],
                        [qsTr("Squat (Knees at 90 Degrees)") ,qsTr("Center Body"), qsTr("Push Inward") ],
                        [qsTr("Center Your Upper Body") ,qsTr("Remain Centered") ,qsTr("Push Inward") ],
                        [qsTr("Stand on Toes") ,qsTr("Push Outward") ],
                        [qsTr("Squat (Knees at 90 Degrees)") ,qsTr("Center Body"), qsTr("Push Outward") ],
                        [qsTr("Stand on Toes") ,qsTr("Push Inward") ],
                        [qsTr("Stand on Foot Pedals") ,qsTr("Push Outward"), qsTr("Move Body Side to Side")],
                    ][index];
        }

        function instructions(index) {
            var instr = instructionsList(index)
            return "<ul>" + instr.map(function(s) { return "<li>" + s + "</li>" }).join("") + "</ul>"
        }

        ListElement {
            images: [ ListElement { source: "motion1.jpg" } ]
            icon : "TL1000/C360_TL1000_man_motion_StartupPushOutward.png"
        }
        ListElement {
            images: [ ListElement { source: "motion2.jpg" } ]
            icon : "TL1000/C360_TL1000_man_motion_PushInward.png"
        }
        ListElement {
            images: [ ListElement { source: "motion3.jpg" } ]
            icon : "TL1000/C360_TL1000_man_motion_LegPumpsOutward.png"
        }
        ListElement {
            images: [ ListElement { source: "motion4.jpg" } ]
            icon : "TL1000/C360_TL1000_man_motion_SquatInward.png"
        }
        ListElement {
            images: [ ListElement { source: "motion5.jpg" } ]
            icon : "TL1000/C360_TL1000_man_motion_LegPumpsInward.png"
        }
        ListElement {
            images: [ ListElement { source: "motion6.jpg" } ]
            icon : "TL1000/C360_TL1000_man_motion_StandOnToesPushOutward.png"
        }
        ListElement {
            images: [ ListElement { source: "motion7.jpg" } ]
            icon : "TL1000/C360_TL1000_man_motion_SquatOutward.png"
        }

        ListElement {
            images: [ ListElement { source: "motion8.jpg" } ]
            icon : "TL1000/C360_TL1000_man_motion_StandOnToesPushInward.png"
        }
        ListElement {
            images: [ ListElement { source: "motion9.jpg" } ]
            icon : "TL1000/C360_TL1000_man_motion_RecoverPushOutward.png"
        }
    }

    ListModel {
        id: c360Modes_Elliptical

        function imagePath(productModel) {
            var model = brainboard.modelString ? brainboard.modelString : "XCS900"
            switch(brainboard.modelString) {
            case "TS1000":
                return options.modestyMode ? "graphics/c360/TS1000/Male_Assets/C360_Spectrum_" : "graphics/c360/TS1000/Female_Assets/C360_Spectrum_"
            case "XCS900":
                return options.modestyMode ? "graphics/c360/XCS900/MaleOnly/C360_XCS900_" : "graphics/c360/XCS900/C360_XCS900_"
            case "XCS400":
                return options.modestyMode ? "graphics/c360/XCS900/MaleOnly/C360_XCS900_" : "graphics/c360/XCS400/C360_XCS400_"
            default:
                return options.modestyMode ? "graphics/c360/XCS900/MaleOnly/C360_XCS900_" : "graphics/c360/XCS400/C360_XCS400_"
            }
        }

        function title(index) {
            return [ qsTr("STRIDE FORWARD"),
                    qsTr("STRIDE FORWARD & PUSH ARMS"),
                    qsTr("STAND ON SIDES, LEFT ARM ONLY"),
                    qsTr("STAND ON SIDES, RIGHT ARM ONLY"),
                    qsTr("REVERSE STRIDE & BEND KNEES"),
                    qsTr("STRIDE FORWARD & LIFT HEELS"),
                    qsTr("STRIDE FORWARD & PULL ARMS"),
                    main.isCSA ? qsTr("HOLD CENTER GRIPS, REVERSE STRIDE & LIFT TOES") : qsTr("HOLD SIDE RAILS, REVERSE STRIDE & LIFT TOES"),
                    qsTr("STAND ON SIDES, CHANGE GRIP, PUSH & PULL ARMS"),
                    qsTr("RECOVER - STRIDE FORWARD")
                    ][index]
        }
        function instructionsList(index) {
            return [
                     [qsTr("Feet on Foot Pedals") ,qsTr("Stride Forward")],
                     [qsTr("Stride Forward") ,qsTr("Push Arms") ],
                     [qsTr("Feet On Side Steps") ,qsTr("Bend Knees") ,qsTr("Right Arm on Handrail") ],
                     [qsTr("Feet On Side Steps") ,qsTr("Bend Knees") ,qsTr("Left Arm on Handrail") ],
                     [qsTr("Feet On Pedals") ,qsTr("Reverse Stride") ,qsTr("Bend Knees") ],
                     [qsTr("Stride Forward") ,qsTr("Lift Heels") ],
                     [qsTr("Feet On Pedals") ,qsTr("Stride Forward") ,qsTr("Pull Arms") ],
                     [qsTr("Reverse Stride") ,qsTr("Bend Knees") ,qsTr("Lift Toes") ],
                     [qsTr("Feet On Side Steps") ,qsTr("Bend Knees") ,qsTr("Try Different Grip") ],
                     [qsTr("Feet on Foot Pedals") ,qsTr("Stride Forward")]
                    ][index];
        }

        function instructions(index) {
            var instr = instructionsList(index)
            return "<ul>" + instr.map(function(s) { return "<li>" + s + "</li>" }).join("") + "</ul>"
        }

        ListElement {
            images: [ ListElement { source: "motion1-1.jpg" },
                      ListElement { source: "motion1-2.jpg" }
            ]
            icon : "C360_1-1_Forward.png"
        }
        ListElement {
            images: [ ListElement { source: "motion2-1.jpg" },
                      ListElement { source: "motion2-2.jpg" }
            ]
            icon : "C360_2-1_Forward_Push_Arms.png"
        }
        ListElement {
            images: [ ListElement { source: "motion3-1.jpg" },
                      ListElement { source: "motion3-2.jpg" }
            ]
            icon : "C360_3-1_Left_Arm.png"
        }
        ListElement {
            images: [ ListElement { source: "motion4-1.jpg" },
                      ListElement { source: "motion4-2.jpg" }
            ]
            icon : "C360_4-1_Right_Arm.png"
        }
        ListElement {
            images: [ ListElement { source: "motion5-1.jpg" },
                      ListElement { source: "motion5-2.jpg" }
            ]
            icon : "C360_5-1_Reverse_Bend_Knees.png"
        }
        ListElement {
            images: [ ListElement { source: "motion6-1.jpg" },
                      ListElement { source: "motion6-2.jpg" }
            ]
            icon : "C360_6-1_Forward_Heels.png"
        }
        ListElement {
            images: [ ListElement { source: "motion7-1.jpg" },
                      ListElement { source: "motion7-2.jpg" }
            ]
            icon : "C360_7-1_Forward_Pull_Arms.png"
        }
        ListElement {
            images: [ ListElement { source: "motion8-1.jpg" },
                      ListElement { source: "motion8-2.jpg" }
            ]
            icon : "C360_8-1_Hold_Side_Rails.png"
        }
        ListElement {
            images: [ ListElement { source: "motion9-1.jpg" },
                      ListElement { source: "motion9-2.jpg" }
            ]
            icon : "C360_9-1_Stand_On_Sides.png"
        }
        ListElement {
            images: [ ListElement { source: "motion10-1.jpg" },
                      ListElement { source: "motion10-2.jpg" }
            ]
            icon : "C360_10-1_Recover.png"
        }
    }

}

